@@ -1,7 +1,11 @@
+from __future__ import annotations
+
 try:
-    import importlib.resources as importlib_resources
-except ImportError:
+    # first, try to import the installed package version
     import importlib_resources
+except ImportError:
+    # if it's not installed, assume that the stdlib version is new enough (e.g. py3.10)
+    import importlib.resources as importlib_resources  # type: ignore[no-redef]
 
 import json
 import typing as t
@@ -11,22 +15,24 @@ class NoSuchSchemaError(ValueError):
     pass
 
 
-def _get(package: str, resource: str, name: str) -> t.Dict[str, t.Any]:
+def _get(package: str, resource: str, name: str) -> dict[str, t.Any]:
     try:
-        return json.loads(importlib_resources.read_text(package, resource))
+        return json.loads(
+            importlib_resources.files(package).joinpath(resource).read_bytes()
+        )
     except (FileNotFoundError, ModuleNotFoundError):
         raise NoSuchSchemaError(f"no builtin schema named {name} was found")
 
 
-def _get_vendored_schema(name: str) -> t.Dict[str, t.Any]:
+def _get_vendored_schema(name: str) -> dict[str, t.Any]:
     return _get("check_jsonschema.builtin_schemas.vendor", f"{name}.json", name)
 
 
-def _get_custom_schema(name: str) -> t.Dict[str, t.Any]:
+def _get_custom_schema(name: str) -> dict[str, t.Any]:
     return _get("check_jsonschema.builtin_schemas.custom", f"{name}.json", name)
 
 
-def get_builtin_schema(name: str) -> t.Optional[t.Dict[str, t.Any]]:
+def get_builtin_schema(name: str) -> dict[str, t.Any]:
     # first, look for an identifying prefix
     if name.startswith("vendor."):
         return _get_vendored_schema(name[7:])
