@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import sys
 import typing as t
 
@@ -10,6 +12,7 @@ from .loaders import (
     InstanceLoader,
     SchemaLoaderBase,
     SchemaParseError,
+    UnsupportedUrlScheme,
 )
 
 
@@ -24,7 +27,7 @@ class SchemaChecker:
         schema_loader: SchemaLoaderBase,
         instance_loader: InstanceLoader,
         *,
-        format_opts: t.Optional[FormatOptions] = None,
+        format_opts: FormatOptions | None = None,
         traceback_mode: str = "short",
         show_all_errors: bool = False,
     ):
@@ -35,19 +38,21 @@ class SchemaChecker:
         self._traceback_mode = traceback_mode
         self._show_all_errors = show_all_errors
 
-    def _fail(self, msg: str, err: t.Optional[Exception] = None) -> t.NoReturn:
+    def _fail(self, msg: str, err: Exception | None = None) -> t.NoReturn:
         print(msg, file=sys.stderr)
         if err is not None:
             utils.print_error(err, mode=self._traceback_mode)
         raise _Exit(1)
 
-    def get_validator(self, filename: str, doc: t.Dict[str, t.Any]):
+    def get_validator(self, filename: str, doc: dict[str, t.Any]):
         try:
             return self._schema_loader.get_validator(filename, doc, self._format_opts)
         except SchemaParseError as e:
             self._fail("Error: schemafile could not be parsed as JSON", e)
         except jsonschema.SchemaError as e:
             self._fail(f"Error: schemafile was not valid: {e}\n", e)
+        except UnsupportedUrlScheme as e:
+            self._fail(f"Error: {e}\n", e)
         except Exception as e:
             self._fail("Error: Unexpected Error building schema validator", e)
 
@@ -64,10 +69,10 @@ class SchemaChecker:
     def _run(self) -> None:
         try:
             errors = self._build_error_map()
-        except jsonschema.RefResolutionError as err:
-            self._fail("Failure resolving $ref within schema\n", err)
-        except BadFileTypeError as err:
-            self._fail("Failure while loading instance files\n", err)
+        except jsonschema.RefResolutionError as e:
+            self._fail("Failure resolving $ref within schema\n", e)
+        except BadFileTypeError as e:
+            self._fail("Failure while loading instance files\n", e)
 
         if errors:
             print("Schema validation errors were encountered.")
